import akiwi.app as kiwi

def main():
    app = kiwi.Application()
    return app.run_with_command()

if __name__ == "__main__":
    main()